/*
** Copyright (C) 1999 Christian Werner
**
** This program and library is free software; you can redistribute it and/or
** modify it under the terms of the GNU (Library) General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU (Library) General Public License for more details.
**
** You should have received a copy of the GNU (Library) General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package swishej;

import java.io.*;

/**
 * Reader for reading a SWISH-E index file from a RandomAccessFile.
 * @see swishej.Reader
 */

class FReader extends RandomAccessFile implements Reader {
    /**
     * Create an index file reader from a file
     * @param file file for the index file reader
     * @return number of bytes read
     * @exception IOException if an error occurred
     */
    FReader(File file) throws IOException {
        super(file, "r");
    }

    /**
     * Create an index file reader from a filename
     * @param string filename for the index file reader
     * @exception IOException if an error occurred
     */
    FReader(String string) throws IOException {
        super(string, "r");
    }

    /**
     * Retrieve current file position
     * @return current file position
     */
    public long tell() {
        try {
	    return getFilePointer();
	} catch (Exception e) {
	}
	return 0;
    }
}
